@@ -2,10 +2,10 @@ import pandas
 from enum import Enum
 
 # urls of CSV, from which the tickers will be extracted
-_NYSE_URL = 'https://old.nasdaq.com/screening/companies-by-name.aspx?letter=0&exchange=nyse&render=download'
-_NASDAQ_URL = 'https://old.nasdaq.com/screening/companies-by-name.aspx?letter=0&exchange=nasdaq&render=download'
-_AMEX_URL = 'https://old.nasdaq.com/screening/companies-by-name.aspx?letter=0&exchange=amex&render=download'
-_URL_LIST = [_NYSE_URL, _NASDAQ_URL, _AMEX_URL]
+NYSE_URL = 'https://old.nasdaq.com/screening/companies-by-name.aspx?letter=0&exchange=nyse&render=download'
+NASDAQ_URL = 'https://old.nasdaq.com/screening/companies-by-name.aspx?letter=0&exchange=nasdaq&render=download'
+AMEX_URL = 'https://old.nasdaq.com/screening/companies-by-name.aspx?letter=0&exchange=amex&render=download'
+
 
 class Region(Enum):
     AFRICA = 'AFRICA'
@@ -22,18 +22,11 @@ class Region(Enum):
 def get_tickers(NYSE=True, NASDAQ=True, AMEX=True):
     tickers_list = []
     if NYSE:
-        tickers_list.extend(__url2list(_NYSE_URL))
+        tickers_list.extend(__url2list(NYSE_URL))
     if NASDAQ:
-        tickers_list.extend(__url2list(_NASDAQ_URL))
+        tickers_list.extend(__url2list(NASDAQ_URL))
     if AMEX:
-        tickers_list.extend(__url2list(_AMEX_URL))
-    return tickers_list
-
-
-def get_tickers_filtered(mktcap_min=None, mktcap_max=None):
-    tickers_list = []
-    for url in _URL_LIST:
-        tickers_list.extend(__url2list_filtered(url, mktcap_min=mktcap_min, mktcap_max=mktcap_max))
+        tickers_list.extend(__url2list(AMEX_URL))
     return tickers_list
 
 
@@ -47,24 +40,10 @@ def get_tickers_by_region(region):
 
 def __url2list(url):
     df = pandas.read_csv(url)
-    # removes weird tickers
     df_filtered = df[~df['Symbol'].str.contains("\.|\^")]
     return df_filtered['Symbol'].tolist()
 
 
-def __url2list_filtered(url, mktcap_min=None, mktcap_max=None):
-    df = pandas.read_csv(url)
-    df = df.dropna(subset={'MarketCap'})
-    df = df[~df['Symbol'].str.contains("\.|\^")]
-    df['MarketCap'] = df['MarketCap'].apply(lambda x: float(x[1:-1]) if 'M' in x else float(x[1:-1]) * 1000)
-
-    if mktcap_min is not None:
-        df = df[df['MarketCap'] > mktcap_min]
-    if mktcap_max is not None:
-        df = df[df['MarketCap'] < mktcap_max]
-    return df['Symbol'].tolist()
-
-
 # save the tickers to a CSV
 def save_tickers(NYSE=True, NASDAQ=True, AMEX=True, filename='tickers.csv'):
     tickers = get_tickers(NYSE, NASDAQ, AMEX)
@@ -99,11 +78,3 @@ if __name__ == '__main__':
 
     # save tickers from Europe
     save_tickers_by_region(Region.EUROPE, filename='EU_tickers.csv')
-    
-    # get tickers filtered by market cap (in millions)
-    filtered_tickers = get_tickers_filtered(mktcap_min=500, mktcap_max=2000)
-    print(filtered_tickers[:5])
-
-    # not setting max will get stocks with $200 million market cap and up.
-    filtered_tickers = get_tickers_filtered(mktcap_min=200)
-    print(filtered_tickers[:5])
